==> haskell-doctest-0.16.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0
id: doctest-0.16.0-HHMgKtyqVYiIgv8jHZr3Zd
key: doctest-0.16.0-HHMgKtyqVYiIgv8jHZr3Zd
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: a4764bdf0c181d4501169c50726034f7
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.16.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.16.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/doctest-0.16.0
hs-libraries: HSdoctest-0.16.0-HHMgKtyqVYiIgv8jHZr3Zd
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 ghc-8.4.3
    ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h process-1.6.3.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=ac79c284619ed805973e8a29b0490575
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h=1ca664f4ad2827a0272e205999740579
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.16.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0
id: doctest-0.16.0-LCL8zGzzo4D5I3N3tcHzbX
key: doctest-0.16.0-LCL8zGzzo4D5I3N3tcHzbX
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: 417783d7f8be0eaf331f7faba8858768
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.16.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/doctest-0.16.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/doctest-0.16.0
hs-libraries: HSdoctest-0.16.0-LCL8zGzzo4D5I3N3tcHzbX
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 ghc-8.4.3
    ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h process-1.6.3.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             code-page-0.1.3-78bf3rlibAi1l7KbTfbq3V=ac79c284619ed805973e8a29b0490575
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             ghc-paths-0.1.0.9-BTJEJFO7ixU1hUjA8BfQ4h=1ca664f4ad2827a0272e205999740579
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
